@@ -11,7 +11,7 @@ use warnings;
 
 @ISA = qw(SOAP::Lite);
 
-$VERSION = "1.23";
+$VERSION = "1.24";
 
 # SOAP::Lite has changed the name for speciying a schema in 0.6?
 # method before: schema
@@ -59,9 +59,9 @@ sub wsdlinit
 	} ## end if ( $self->{ _WSDL }->...
 	unless ( $xpath )
 	{
-		$xpath =
-		  XML::XPath->new(
-			xml => SOAP::Schema->new( $SCHEMA_URL => $self->wsdl() )->access );
+	    no strict qw(refs);
+		$xpath = XML::XPath->new(
+			xml => $self->schema->$SCHEMA_URL( $self->wsdl() )->access );
 	} ## end unless ( $xpath )
 
 	( $xpath )
@@ -1567,7 +1567,7 @@ Replace whitespace by '@' in E-Mail addresses.
 =head1 SVN information
 
  $LastChangedBy: kutterma $
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/1.21/lib/SOAP/WSDL.pm $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/1.21/lib/SOAP/WSDL.pm $
  $Rev: 20 $
 
 =cut
